<?php
/*
* search page, for when search.module is disabled
*/

function solr_help($section){
  switch ($section){
    case 'search/node':
      return t('<p>Search all the items in @site. Examples: !smurfs, !therm*</p>', array(
        '@site' => variable_get('site_name', 'drupal'),
        '!therm*' => l('therm*', 'search/node', NULL, 't=therm*'),
        '!smurfs' => l('smurfs', 'search/node', NULL, 't=smurfs'),
        ));
        
    case 'search/user':
      return t('<p>Search for a @site user by their username.</p>', array(
        '@site' => variable_get('site_name', 'drupal'),
        ));
  }
}

function solr_search_page(){
  if (! arg(1)){
    $type = $_GET['type'] ? $_GET['type'] : variable_get('solr_default_type', 'node');
    drupal_goto("search/$type", ($_GET['t'] ? 't='. $_GET['t'] : NULL));
  }
  
  $type = arg(1);

  if (! node_hook($type, 'solr')){
    drupal_set_message(t('No search is available for this type of content'));
    return '';
  }

  $terms = $_GET['t'];

  $output = array(drupal_get_form('solr_search_form', $terms, $type));

  if ($terms){
    drupal_add_css(drupal_get_path('module', 'solr') . '/solr.css');
    $results = node_invoke($type, 'solr', 'search', $type, $terms);

    if (empty($results)) {
      drupal_set_message(t('Your search yielded no results')); // FIXME: node_invoke or results from solr.module
    }
    else{      
      $search_page = node_hook($type, 'search_page') ? node_invoke($type, 'search_page', $results, $type) : theme('solr_search_page', $results, $type);
      $output[] = theme('box', t('Search results'), $search_page);
    }
  }

  return sprintf('<div id="page-wrapper">%s</div>', implode("\n", $output));
}

function solr_search_form($terms = '', $type) {
  $form = array(
    '#action' => url("search/$type", NULL, NULL, TRUE),
    '#attributes' => array('class' => 'search-form'),
    '#method' => 'get',
    '#base' => 'solr_search_form',
  );
  $form['module'] = array('#type' => 'value', '#value' => $type);
  $form['basic'] = array('#type' => 'item', '#title' => t('Enter your keywords'));
  $form['basic']['inline'] = array('#prefix' => '<div class="container-inline">', '#suffix' => '</div>');
  
  $form['basic']['inline']['t'] = array(
    '#type' => 'textfield',
    '#title' => '',
    '#default_value' => $terms,
    '#size' => 40,
    '#maxlength' => 255,
  );
  
  if ($search_fields = node_invoke($type, 'solr', 'search_fields', $type)){
    $form['basic']['inline']['df'] = array(
      '#type' => 'select',
      '#default_value' => $_GET['df'],
      '#options' => $search_fields,
    );
  }
  
  $form['basic']['inline']['submit'] = array('#type' => 'submit', '#value' => t('search'), '#name' => '');

  return $form;
}

function solr_search_box() {
  if (arg(0) == 'search' && ($arg_type = arg(1))){
    $search_type = $arg_type;
  }
  else {
    $search_type = variable_get('solr_default_type', '');
  }
  
  $form = array(
    '#action' => url("search", NULL, NULL, TRUE),
    '#attributes' => array('class' => 'search-form'),
    '#method' => 'get',
    '#base' => 'solr_search_form',
  );
  
  $form['module'] = array('#type' => 'value', '#value' => $search_type);
  
  $options = array();
  foreach (node_get_types() as $type) {
    if (node_hook($type->type, 'solr') && node_invoke($type, 'solr', 'perm', $type)){
      $options[$type->type] = $type->name;
    }
  }
    
  $form['t'] = array(
    '#type' => 'textfield',
    '#title' => '',
    '#default_value' => $_GET['t'],
    '#size' => 20,
    '#maxlength' => 255,
    '#weight' => 4,
  );
  
  $form['type'] = array(
    '#type' => 'select',
    '#default_value' => $search_type,
    '#options' => $options,
    '#weight' => 2
  );
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Search'),
    '#name' => '',
    '#weight' => -10,
    );

  return $form;
}

function solr_form_alter($form_id, &$form) {
  if ($form_id == 'solr_search_form') {
    unset($form['form_token']);
    unset($form['form_id']);
    unset($form['preview']);
  }
}

